<script setup>
import { ref, nextTick } from 'vue';
import { get, post, postBlob, postForm } from '@/utils/request.js'
import { formatMessage } from '@/utils/localeUtils.js';
import { message } from 'ant-design-vue';

const submitButton = ref(null);
const isSave = ref(true);
const open = ref(false);
const initFormData = {}
let formData = ref(initFormData);
const treeData = ref(null);

const emit = defineEmits(['tableReload'])

const handleOk = (e) => {
    nextTick(() => {
        setTimeout(() => {
            submitButton.value.$el.click();
        }, 100);
    });
};

const onFinish = values => {
    // console.log('Success:', values);
    open.value = false;
    post(isSave.value ? '/api/role/save' : '/api/role/update', formData.value).then((resp) => {
        let result = resp.data;
        if (result.code === 200) {
            message.success(formatMessage('page.update.success', '更新成功'));
        } else {
            message.error(result.msg);
        }
        emit('tableReload', 'reload')
    })
};
const onFinishFailed = errorInfo => {
    console.log('Failed:', errorInfo);
};



defineExpose({
    open,
    formData,
    initFormData,
    treeData,
    isSave,
})

</script>

<script>
export default {
    name: '角色管理-edit'
}
</script>

<template>
    <div>
        <a-modal v-model:open="open"
            :title="isSave ? formatMessage('page.add', '添加') : formatMessage('page.edit', '编辑')" @ok="handleOk"
            style="width: 600px;">
            <a-form :model="formData" name="formTable" :label-col="{ span: 8 }" :wrapper-col="{ span: 16 }"
                style="display: flex;justify-content: space-between;flex-wrap: wrap;" autocomplete="off"
                @finish="onFinish" @finishFailed="onFinishFailed">
                    <a-form-item 
                      label="名称" 
                      name="name" 
                      style="width: 250px;" 
                            :rules="[{ required: true }]"
                            >
                    <a-input 
                        v-model:value="formData.name" 
                     /> 
                        </a-form-item>
                    <a-form-item 
                      label="标识" 
                      name="code" 
                      style="width: 250px;" 
                            >
                    <a-input 
                        v-model:value="formData.code" 
                     /> 
                        </a-form-item>
                    <a-form-item 
                      label="状态" 
                      name="status" 
                      style="width: 250px;" 
                            >
                    <a-select 
                        v-model:value="formData.status" 
                        :options="[
                                { label: '正常', value: 1 },
                                { label: '禁用', value: 0 },
                            ]"
                        >
                    </a-select>
                        </a-form-item>
                    <a-form-item 
                      label="添加时间" 
                      name="createTime" 
                      style="width: 250px;" 
                            >
                    <a-date-picker 
                        v-model:value="formData.createTime" 
                        show-time 
                        format="YYYY-MM-DD HH:mm:ss" 
                        value-format="YYYY-MM-DD HH:mm:ss" 
                     /> 
                        </a-form-item>
                    <a-form-item 
                      label="修改时间" 
                      name="updateTime" 
                      style="width: 250px;" 
                            >
                    <a-date-picker 
                        v-model:value="formData.updateTime" 
                        show-time 
                        format="YYYY-MM-DD HH:mm:ss" 
                        value-format="YYYY-MM-DD HH:mm:ss" 
                     /> 
                        </a-form-item>
                    <a-form-item 
                      label="备注" 
                      name="memo" 
                      style="width: 250px;" 
                            >
                    <a-input 
                        v-model:value="formData.memo" 
                     /> 
                        </a-form-item>

                <a-form-item>
                    <a-button type="primary" html-type="submit" ref="submitButton"
                        style="visibility: hidden;">Submit</a-button>
                </a-form-item>
            </a-form>
        </a-modal>
    </div>
</template>

<style></style>
